This is a public stub of a proprietary EntityRisk package uploaded to protect
users of the EntityRisk PROVEN Platform from
[dependency confusion](https://medium.com/@alex.birsan/dependency-confusion-4a5d60fec610).

This package is non-functional and users accidentally installing it will
receive an error message when trying to import it.
